@@ -475,6 +475,12 @@ wrap.knit_asis = function(x, options, inline = FALSE) {
   knit_hooks$get('output')(x, options)
 }
 
+#' @export
+wrap.knit_asis_list = function(x, options, inline = FALSE) {
+  res = lapply(x, wrap, options = options, inline = inline)
+  paste(unlist(res), collapse = '\n')
+}
+
 #' @export
 wrap.source = function(x, options) {
   src = sub('\n$', '', x$src)
