@@ -5,10 +5,11 @@ g = gframe('An R Notebook based on knitr', use.scrollwindow = TRUE,
            horizontal = FALSE, container = w)
 gbutton('Knit', container = g, handler = function(h, ...) {
   library(knitr)
-  svalue(g2) = try(knit2html(text = svalue(g1), fragment.only = TRUE))
+  svalue(g3) = try(knit2html(text = svalue(g1), fragment.only = TRUE))
 })
 g0 = ggroup(container = g)
 code = readLines(system.file('examples', 'knitr-minimal.Rmd', package = 'knitr'))
 # g1 = gtext(code, container = g, use.codemirror = TRUE, width = 500)
-g1 = gtext(code, container = g0, height = 500, expand = TRUE)
-g2 = ghtml('results here', container = g0, expand = TRUE)
+g1 = gtext(code, container = g0, width = 500, height = 500)
+g2 = ggroup(cont = g0, expand = TRUE)
+g3 = ghtml('results here', container = g2)
